@@ -57,12 +57,12 @@ BOOL cmd_join(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 sObject* line = STRING_NEW_STACK(vector_item(SFD(nextin).mLines, i));
                 string_chomp(line);
                 if(!fd_write(nextout, string_c_str(line), string_length(line))) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
                 if(!fd_write(nextout, field, strlen(field))) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -71,20 +71,20 @@ BOOL cmd_join(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             sObject* line = STRING_NEW_STACK(vector_item(SFD(nextin).mLines, i));
             BOOL chomp = string_chomp(line);
             if(!fd_write(nextout, string_c_str(line), string_length(line))) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(chomp) {
                 if(!fd_write(nextout, field, strlen(field))) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
             }
 
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -145,7 +145,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         buf2[len2] = 0;
                     }
                     else {
-                        err_msg("invalid range", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("invalid range", runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
 
@@ -181,7 +181,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                                 char* str = vector_item(SFD(nextin).mLines, j);
                                 if(!fd_write(nextin2,str,strlen(str))) {
-                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                     return FALSE;
                                 }
@@ -197,7 +197,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 else {
                                     if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen))
                                     {
-                                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                         return FALSE;
                                     }
@@ -214,7 +214,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                                 char* str = vector_item(SFD(nextin).mLines, j);
                                 if(!fd_write(nextin2, str, strlen(str))) {
-                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                     return FALSE;
                                 }
@@ -231,7 +231,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 else {
                                     if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen))
                                     {
-                                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                         return FALSE;
                                     }
@@ -254,7 +254,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     if(num >= 0 && num < vector_count(SFD(nextin).mLines)) {
                         char* str = vector_item(SFD(nextin).mLines, num);
                         if(!fd_write(nextin2, str, strlen(str))){
-                            err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                            err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                             return FALSE;
                         }
@@ -263,7 +263,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         switch(lf) {
                             case kCRLF:
                                 if(!fd_write(nextin2, "\r\n", 2)) {
-                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                     return FALSE;
                                 }
@@ -271,7 +271,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                             case kCR:
                                 if(!fd_writec(nextin2, '\r')) {
-                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                     return FALSE;
                                 }
@@ -279,7 +279,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                             case kLF:
                                 if(!fd_writec(nextin2, '\n')) {
-                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                     return FALSE;
                                 }
@@ -287,7 +287,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                             case kBel:
                                 if(!fd_writec(nextin2, '\a')) {
-                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                     return FALSE;
                                 }
@@ -307,7 +307,7 @@ BOOL cmd_lines(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     else {
                         if(!fd_write(nextout, SFD(nextin2).mBuf, SFD(nextin2).mBufLen))
                         {
-                            err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                            err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                             return FALSE;
                         }
@@ -513,7 +513,7 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 for(i=0; i<vector_count(SFD(nextin).mLines); i++) {
                     char* line = vector_item(SFD(nextin).mLines, i);
                     if(!fd_write(nextout, line, strlen(line))) {
-                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
                     }
@@ -540,7 +540,7 @@ BOOL cmd_sort(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 for(i=0; i<vector_count(SFD(nextin).mLines); i++) {
                     char* line = vector_item(SFD(nextin).mLines, i);
                     if(!fd_write(nextout, line, strlen(line))) {
-                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
                     }
@@ -600,7 +600,7 @@ BOOL cmd_combine(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 if(n < vector_count(SFD(nextout2[i]).mLines)) {
                     char* line = vector_item(SFD(nextout2[i]).mLines, n);
                     if(!fd_write(nextout, line, strlen(line))) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
                     }
