@@ -31,7 +31,7 @@ BOOL cmd_exit(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
     else {
         if(vector_count(gJobs) > 0) {
-            err_msg("jobs exist", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("jobs exist", runinfo->mSName, runinfo->mSLine);
             return FALSE;
         }
 
@@ -167,18 +167,18 @@ BOOL cmd_print(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int i;
         for(i=1; i<runinfo->mArgsNumRuntime-1; i++) {
             if(!fd_write(out, runinfo->mArgsRuntime[i], strlen(runinfo->mArgsRuntime[i]))) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(out, " ", 1)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
         }
         if(!fd_write(out, runinfo->mArgsRuntime[i], strlen(runinfo->mArgsRuntime[i]))) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -187,7 +187,7 @@ BOOL cmd_print(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     else if(runinfo->mFilter) {
         if(sRunInfo_option(runinfo, "-read-from-error")) {
             if(!fd_write(out, SFD(gStderr).mBuf, SFD(gStderr).mBufLen)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -195,7 +195,7 @@ BOOL cmd_print(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else {
             if(!fd_write(out, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -224,7 +224,7 @@ BOOL cmd_try(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             else {
                 sObject* nextin2 = FD_NEW_STACK();
                 if(!fd_write(nextin2, string_c_str(gErrMsg), string_length(gErrMsg))) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -251,7 +251,7 @@ BOOL cmd_try(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 BOOL cmd_errmsg(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     if(!fd_write(nextout, string_c_str(gErrMsg), string_length(gErrMsg))) {
-        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
         return FALSE;
     }
@@ -263,7 +263,7 @@ BOOL cmd_errmsg(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 BOOL cmd_raise(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     if(runinfo->mArgsNumRuntime == 2) {
-        err_msg(runinfo->mArgsRuntime[1], runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg(runinfo->mArgsRuntime[1], runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
 
@@ -279,7 +279,7 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, BUFSIZ, "%d objects deleted\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -295,7 +295,7 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             if(item) {
                 if(!IS_USER_OBJECT(item)) {
-                    err_msg("it's not user object. can't delete", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("it's not user object. can't delete", runinfo->mSName, runinfo->mSLine);
                     return FALSE;
                 }
 
@@ -321,7 +321,7 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, BUFSIZ, "%d objects deleted\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -341,7 +341,7 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                 if(item) {
                     if(!IS_USER_OBJECT(item)) {
-                        err_msg("it's not user object. can't delete", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("it's not user object. can't delete", runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
 
@@ -385,7 +385,7 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mBlocksNum > 0) {
         int rcode;
         if(!run(runinfo->mBlocks[0], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
-            err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = rcode;
             return FALSE;
         }
@@ -402,14 +402,14 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         snprintf(buf2, BUFSIZ, "%s %d: eval", runinfo->mSName, runinfo->mSLine);
         if(parse(buf, buf2, &sline, block, NULL)) {
             if(!run(block, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
-                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = rcode;
                 stack_end_stack();
                 return FALSE;
             }
         }
         else {
-            err_msg_adding("parser error\n", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg_adding("parser error\n", runinfo->mSName, runinfo->mSLine);
             stack_end_stack();
             return FALSE;
         }
@@ -430,14 +430,14 @@ BOOL cmd_eval(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         if(parse(buf, buf2, &sline, block, NULL)) {
             sObject* nextin2 = FD_NEW_STACK();
             if(!run(block, nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
-                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = rcode;
                 stack_end_stack();
                 return FALSE;
             }
         }
         else {
-            err_msg_adding("parser error\n", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg_adding("parser error\n", runinfo->mSName, runinfo->mSLine);
             stack_end_stack();
             return FALSE;
         }
@@ -466,13 +466,13 @@ BOOL cmd_msleep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             int size = snprintf(buf, 32, "%c\033[D", c[i % 3]);
 
             if(!fd_write(nextout, buf, size)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(nextout == gStdout) {
                 if(!fd_flash(nextout, 1)) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -494,7 +494,7 @@ BOOL cmd_stackinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     int size = snprintf(buf, BUFSIZ, "slot size %d\npool size %d\nall object number %d\n", stack_slot_size(), stack_page_size(), stack_slot_size()*stack_page_size());
 
     if(!fd_write(nextout, buf, size)) {
-        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
         return FALSE;
     }
@@ -516,12 +516,12 @@ BOOL cmd_stackframe(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             char* key = uobject_loop_key(it);
 
             char* obj_kind[T_TYPE_MAX] = {
-                NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "file dicriptor", "job", "object", "function", "class", "external program", "completion", "external object", "alias"
+                NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "file dicriptor", "job", "object", "function", "class", "external program", "completion", "external object", "alias", "int"
             };
             int size = snprintf(buf, BUFSIZ, "%s: %s\n", key, obj_kind[STYPE(object2)]);
 
             if(!fd_write(nextout, buf, size)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -585,7 +585,7 @@ BOOL cmd_funinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, BUFSIZ, "source name: %s\nsource line: %d\nrun nest level: %d\ncurrent object: %s\nreciever object: %s\ncommand name: %s\n", runinfo2->mSName, runinfo2->mSLine, runinfo2->mNestLevel, current_object, reciever_object, command_name);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -603,7 +603,7 @@ BOOL cmd_gcinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     int size = snprintf(buf, BUFSIZ, "free objects %d\nused objects %d\nall object number %d\nslot size %d\npool size %d\n", gc_free_objects_num(), gc_used_objects_num(), gc_slot_size()*gc_pool_size(), gc_slot_size(), gc_pool_size());
 
     if(!fd_write(nextout, buf, size)) {
-        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
         return FALSE;
     }
@@ -636,7 +636,7 @@ BOOL cmd_time(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 1024, "%d sec(%d minuts %d sec)\n", sec, minuts, sec2);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -712,7 +712,7 @@ static BOOL xyzsh_seek_external_programs(char* path, sObject* sys, char* sname,
     else {
         char buf[BUFSIZ];
         snprintf(buf, BUFSIZ, "%s is invalid path", path);
-        err_msg(buf, sname, sline, "rehash");
+        err_msg(buf, sname, sline);
         //return FALSE;
     }
 
@@ -723,7 +723,7 @@ BOOL xyzsh_rehash(char* sname, int sline)
 {
     char* path = getenv("PATH");
     if(path == NULL) {
-        err_msg("PATH environment variables is NULL", sname, sline, "rehash");
+        err_msg("PATH environment variables is NULL", sname, sline);
         return FALSE;
     }
 
@@ -813,7 +813,7 @@ BOOL cmd_ablock(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                 if(!fd_write(nextout, buf, size))
                 {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -836,7 +836,7 @@ BOOL cmd_ablock(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 int rcode = 0;
                 if(!run(block, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) 
                 {
-                    err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = rcode;
                     return FALSE;
                 }
@@ -858,7 +858,7 @@ BOOL cmd_ablock(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                 if(!fd_write(nextout, SBLOCK(block).mSource, strlen(SBLOCK(block).mSource)))
                 {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -892,12 +892,12 @@ BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     else {
         if(gKanjiCode == kUtf8) {
             if(!fd_write(nextout, "utf8", 4)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -906,12 +906,12 @@ BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else if(gKanjiCode == kByte) {
             if(!fd_write(nextout, "byte", 4)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -920,12 +920,12 @@ BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else if(gKanjiCode == kSjis) {
             if(!fd_write(nextout, "sjis", 4)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -934,12 +934,12 @@ BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else if(gKanjiCode == kEucjp) {
             if(!fd_write(nextout, "eucjp", 5)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             if(!fd_write(nextout, "\n", 1)) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -959,13 +959,13 @@ BOOL cmd_jobs(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         sObject* job = vector_item(gJobs, i);
         int size = snprintf(buf, BUFSIZ, "[%d] %s (pgrp: %d)", i+1, SJOB(job).mName, SJOB(job).mPGroup);
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
 
         if(!fd_write(nextout, "\n", 1)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
