@@ -184,16 +184,16 @@ static void selector_search_backward(sObject* nextin, char* search_str, int* cur
 BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     if(isatty(0) == 0 || isatty(1) == 0) {
-        err_msg("selector: stdin or stdout is not a tty", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("selector: stdin or stdout is not a tty", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
     if(tcgetpgrp(0) != getpgid(0)) {
-        err_msg("selector: not forground process group", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("selector: not forground process group", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
     char* term_env = getenv("TERM");
     if(term_env == NULL || strcmp(term_env, "") == 0) {
-        err_msg("selector: not TERM environment variable setting", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("selector: not TERM environment variable setting", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
 
@@ -236,7 +236,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         while(p - SFD(nextin).mBuf < SFD(nextin).mBufLen) {
             if(*p == '\n') {
                 if(!fd_writec(nextin2, *p)) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -244,12 +244,12 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
             else if(*p >= 0 && *p <= 31) {
                 if(!fd_writec(nextin2, '^')) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
                 if(!fd_writec(nextin2, *p+'@')) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -257,7 +257,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
             else {
                 if(!fd_writec(nextin2, *p)) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -355,7 +355,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     cursor = 0;
                 }
                 else if(key == 'q' || key == 3 || key == 7) {
-                    err_msg("canceled", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("canceled", runinfo->mSName, runinfo->mSLine);
                     endwin();
                     mrestore_screen();
                     mrestore_ttysettings();
@@ -425,7 +425,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                             if(markfiles[k]) {
                                 char* str = vector_item(SFD(nextin2).mLines, k);
                                 if(!fd_write(nextout,str, strlen(str))) {
-                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                     FREE(markfiles);
                                     return FALSE;
@@ -438,7 +438,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         if(!flg_mark) {
                             char* str = vector_item(SFD(nextin2).mLines, cursor);
                             if(!fd_write(nextout, str, strlen(str))) {
-                                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                 FREE(markfiles);
                                 return FALSE;
@@ -448,7 +448,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     else {
                         char* str = vector_item(SFD(nextin2).mLines, cursor);
                         if(!fd_write(nextout, str, strlen(str))) {
-                            err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                            err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                             FREE(markfiles);
                             return FALSE;
@@ -508,16 +508,16 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     if(isatty(0) == 0 || isatty(1) == 0) {
-        err_msg("p: stdin or stdout is not a tty", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("p: stdin or stdout is not a tty", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
     if(tcgetpgrp(0) != getpgid(0)) {
-        err_msg("p: not forground process group", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("p: not forground process group", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
     char* term_env = getenv("TERM");
     if(term_env == NULL || strcmp(term_env, "") == 0) {
-        err_msg("p: not TERM environment variable setting", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("p: not TERM environment variable setting", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
 
@@ -545,7 +545,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         while(p - SFD(nextin).mBuf < SFD(nextin).mBufLen) {
             if(*p == '\n') {
                 if(!fd_writec(nextin2, *p)) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -553,12 +553,12 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
             else if(*p >= 0 && *p <= 31) {
                 if(!fd_writec(nextin2, '^')) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
                 if(!fd_writec(nextin2, *p+'@')) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -566,7 +566,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
             else {
                 if(!fd_writec(nextin2, *p)) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -575,7 +575,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
 
         if(!fd_write(nextin2, "[EOF]", 5)) {
-            err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -721,7 +721,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 selector_search_backward(nextin2, string_c_str(search_str), &cursor);
             }
             else if(key == 'q' || key == 3 || key == 7) {
-                err_msg("p: canceled", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("p: canceled", runinfo->mSName, runinfo->mSLine);
                 endwin();
                 mrestore_screen();
                 mrestore_ttysettings();
@@ -730,7 +730,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
             else if(key == 10 || key == 13) {
                 if(!fd_write(nextout, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
-                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     FREE(markfiles);
                     return FALSE;
@@ -785,16 +785,16 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 BOOL cmd_readline(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     if(isatty(0) == 0 || isatty(1) == 0) {
-        err_msg("readline: stdin or stdout is not a tty", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("readline: stdin or stdout is not a tty", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
     if(tcgetpgrp(0) != getpgid(0)) {
-        err_msg("readline: not forground process group", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("readline: not forground process group", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
     char* term_env = getenv("TERM");
     if(term_env == NULL || strcmp(term_env, "") == 0) {
-        err_msg("readline: not TERM environment variable setting", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("readline: not TERM environment variable setting", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
 
@@ -811,7 +811,7 @@ BOOL cmd_readline(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         if(buf) {
             if(!fd_write(nextout, buf, strlen(buf))) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 FREE(buf);
                 return FALSE;
@@ -830,7 +830,7 @@ BOOL cmd_readline(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         if(buf) {
             if(!fd_write(nextout, buf, strlen(buf))) {
-                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 FREE(buf);
                 return FALSE;
@@ -1167,16 +1167,16 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     BOOL multiple = sRunInfo_option(runinfo, "-multiple");
 
     if(isatty(0) == 0 || isatty(1) == 0) {
-        err_msg("fselector: stdin or stdout is not a tty", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("fselector: stdin or stdout is not a tty", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
     if(tcgetpgrp(0) != getpgid(0)) {
-        err_msg("fselector: not forground process group", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("fselector: not forground process group", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
     char* term_env = getenv("TERM");
     if(term_env == NULL || strcmp(term_env, "") == 0) {
-        err_msg("fselector: not TERM environment variable setting", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+        err_msg("fselector: not TERM environment variable setting", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
 
@@ -1323,7 +1323,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 break;
             }
             else if(key == 'q' || key == 3 || key == 7) {
-                err_msg("canceled", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("canceled", runinfo->mSName, runinfo->mSLine);
                 endwin();
                 mrestore_screen();
                 mrestore_ttysettings();    // 端末の設定の復帰
@@ -1411,7 +1411,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                 if(!fd_write(nextout, cursor_path2, strlen(cursor_path2)))
                 {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     int i;
                     for(i=0; i<vector_count(v); i++) {
                         sFile_delete(vector_item(v, i));
@@ -1423,7 +1423,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 xstrncat(cursor_path, "\n", PATH_MAX+1);
                 if(!fd_write(nextout, cursor_path, strlen(cursor_path)))
                 {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     int i;
                     for(i=0; i<vector_count(v); i++) {
                         sFile_delete(vector_item(v, i));
@@ -1450,7 +1450,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                     if(!fd_write(nextout, full_path2, strlen(full_path2)))
                     {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                         int i;
                         for(i=0; i<vector_count(v); i++) {
                             sFile_delete(vector_item(v, i));
@@ -1462,7 +1462,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     xstrncat(full_path, "\n", PATH_MAX+1);
                     if(!fd_write(nextout, full_path, strlen(full_path)))
                     {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                         int i;
                         for(i=0; i<vector_count(v); i++) {
                             sFile_delete(vector_item(v, i));
@@ -1512,7 +1512,7 @@ BOOL cmd_curses_getch(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         char buf[BUFSIZ];
         int n = snprintf(buf, BUFSIZ, "%d\n", key);
         if(!fd_write(nextout, buf, n)) {
-            err_msg("interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -1653,7 +1653,7 @@ BOOL cmd_curses_printw(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         free(buf);
                     }
                     else {
-                        err_msg("invalid format at printf", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("invalid format at printf", runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
                 }
