@@ -39,7 +39,7 @@ BOOL cmd_write(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else {
             if(access(fname, F_OK) == 0) {
-                err_msg("The file exists. If you want to override, add -force option to \"write\" runinfo", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("The file exists. If you want to override, add -force option to \"write\" runinfo", runinfo->mSName, runinfo->mSLine);
                 return FALSE;
             }
 
@@ -48,21 +48,21 @@ BOOL cmd_write(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         if(sRunInfo_option(runinfo, "-error")) {
             if(!bufsiz_write(fd, SFD(gStderr).mBuf, SFD(gStderr).mBufLen)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
             fd_clear(gStderr);
 
             if(!fd_write(nextout, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
         }
         else {
             if(!bufsiz_write(fd, SFD(nextin).mBuf, SFD(nextin).mBufLen)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
@@ -281,12 +281,12 @@ BOOL cmd_pushd(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     vector_add(gDirStack, STRING_NEW_GC(path2, FALSE));
 
                     if(!fd_write(nextout, path2, strlen(path2))) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
                     }
                     if(!fd_write(nextout, "\n", 1)) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
                     }
@@ -328,18 +328,18 @@ BOOL cmd_expand_tilda(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     sObject* item = hash_loop_item(it);
 
                     if(!fd_write(nextout, string_c_str(item), string_length(item))) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
                     }
                     if(!fd_writec(nextout, '/')) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
                     }
                     char* p = target + strlen(key);
                     if(!fd_write(nextout, p, strlen(p))) {
-                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                        err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
                     }
@@ -353,7 +353,7 @@ BOOL cmd_expand_tilda(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             if(!found) {
                 if(!fd_write(nextout, target, SFD(nextin).mBufLen)) {
-                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                    err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
@@ -361,7 +361,7 @@ BOOL cmd_expand_tilda(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else {
             if(!fd_write(nextout, target, SFD(nextin).mBufLen)) {
-                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+                err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                 return FALSE;
             }
