@@ -2058,9 +2058,8 @@ _rl_event_read_char(EditLine *el, char *cp)
 #if defined(FIONREAD)
 		if (ioctl(el->el_infd, FIONREAD, &n) < 0)
 			return -1;
-		if (n) {
+		if (n)
 			num_read = read(el->el_infd, cp, (size_t)1);
-}
 		else
 			num_read = 0;
 #elif defined(F_SETFL) && defined(O_NDELAY)
